﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Infragistics.WebUI.Data;
using Infragistics.WebUI.WebSchedule;
using Infragistics.WebUI.Shared;

namespace WebMonthView_Bug
{
    public class WebScheduleTestProvider : WebScheduleDataProviderBase, IDataFetch, IDataUpdate
    {
        public WebScheduleTestProvider()
        {
            System.Threading.Thread.CurrentThread.CurrentUICulture = new System.Globalization.CultureInfo("en-US");
            System.Threading.Thread.CurrentThread.CurrentCulture = new System.Globalization.CultureInfo("en-US");
        }
        #region IDataFetch Members

        /// <summary>
        /// Fetches WebSchedule objects from the underlying data source.
        /// </summary>
        /// <param name="context">A <b>DataContext</b> subclass containing
        /// parameter values for use when carrying out a fetch operation.</param>
        /// <remarks>
        /// 	<p class="body">The implementation of <b>Fetch</b> will ordinarily
        /// examine the <see cref="!:DataContext.OperationName">OperationName</see>
        /// of the supplied context (parameters for the select or retrieval
        /// operation), and dispatch it to another method specifically designed
        /// for performing the requested operation.</p>
        /// 	<p class="body">In addition to naming the operation, the supplied
        /// <b>DataContext</b> will also encapsulate all of the information
        /// necessary to perform the operation. Examples of this sort of
        /// information would include key values, range boundaries, or any
        /// other material that would serve as criterion for the selection
        /// of information to return from the data source.</p>
        /// 	<p class="body">The included WebSchedule data providers already
        /// implement <b>IDataFetch</b>, so most developers do not need to
        /// contemplate implementing this interface unless they want to
        /// extend the functionality of the WebSchedule data model with
        /// their own custom data provider.</p>
        /// </remarks>
        public void Fetch(DataContext context)
        {
            if (context == null)
                throw new ArgumentNullException("context");

            this.RegisterDataBindings(context);

            // Test the Operation for null so StartsWith does not fail.
            if ((context.Operation != null) && context.Operation.StartsWith("FetchResource"))
            {
                this.FetchResource(context as FetchResourcesContext);
            }
            else
            {
                switch (context.Operation)
                {
                    case "FetchActivities":
                        this.FetchActivities(context as FetchActivitiesContext);
                        break;
                    case "FetchReminders":
                        this.FetchReminders(context as FetchRemindersContext);
                        break;
                    case "FetchRecurrences":
                        this.FetchRecurrences(context as FetchRecurrencesContext);
                        break;
                    case "FetchVariances":
                        this.FetchVariances(context as FetchVariancesContext);
                        break;
                    default:
                        throw new ArgumentException("Invalid DataContext");
                }
            }
        }

        private void FetchResource(FetchResourcesContext context)
        {
            // there are no resources to fetch
        }

        private void FetchActivities(FetchActivitiesContext context)
        {
            context.Activities.Clear();

            var activities = ((System.Collections.IList)context.Activities);

            // Activate or deactivate the following event to reproduce the Bug.

            // ------------------------------------------------------------------------------------------

            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "STI-258926",
                Subject = "Event 1",
                StartDateTime = SmartDate.Parse("2/13/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("2/17/2012 11:59:59 PM"),
                AllDayEvent = true,
            });

            // ------------------------------------------------------------------------------------------

            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "CMME-258977",
                Subject = "Event 2",
                StartDateTime = SmartDate.Parse("2/13/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("2/13/2012 12:00:00 AM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "CMME-258923",
                Subject = "Event 3",
                StartDateTime = SmartDate.Parse("2/15/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("2/15/2012 12:00:00 AM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "EVT-258639",
                Subject = "Event 4",
                StartDateTime = SmartDate.Parse("2/29/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("3/7/2012 11:59:59 PM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "CMME-259462",
                Subject = "Event 5",
                StartDateTime = SmartDate.Parse("2/15/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("2/15/2012 12:00:00 AM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "CMME-258922",
                Subject = "Event 6",
                StartDateTime = SmartDate.Parse("2/14/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("2/14/2012 12:00:00 AM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "CMME-258924",
                Subject = "Event 7",
                StartDateTime = SmartDate.Parse("2/16/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("2/16/2012 12:00:00 AM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "INS-258719",
                Subject = "Event 8",
                StartDateTime = SmartDate.Parse("3/5/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("3/16/2012 11:59:59 PM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "CMME-258920",
                Subject = "Event 9",
                StartDateTime = SmartDate.Parse("2/13/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("2/13/2012 12:00:00 AM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "CMME-258921",
                Subject = "Event 10",
                StartDateTime = SmartDate.Parse("2/14/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("2/14/2012 12:00:00 AM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "CMME-258552",
                Subject = "Event 11",
                StartDateTime = SmartDate.Parse("1/10/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("1/10/2012 12:00:00 AM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "INS-259061",
                Subject = "Event 12",
                StartDateTime = SmartDate.Parse("1/26/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("2/1/2012 11:59:59 PM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "EVT-259340",
                Subject = "Event 13",
                StartDateTime = SmartDate.Parse("1/9/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("1/9/2012 12:00:00 AM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "FME-258919",
                Subject = "Event 14",
                StartDateTime = SmartDate.Parse("3/2/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("3/4/2012 11:59:59 PM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "ICW-256625",
                Subject = "Event 15",
                StartDateTime = SmartDate.Parse("2/29/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("2/29/2012 12:00:00 AM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "CON-259169",
                Subject = "Event 16",
                StartDateTime = SmartDate.Parse("2/10/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("2/10/2012 12:00:00 AM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "CMME-258925",
                Subject = "Event 17",
                StartDateTime = SmartDate.Parse("2/16/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("2/16/2012 12:00:00 AM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "CMME-258954",
                Subject = "Event 18",
                StartDateTime = SmartDate.Parse("2/13/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("2/13/2012 12:00:00 AM"),
                AllDayEvent = true,
            });
            activities.Add(new Appointment(this.WebScheduleInfo)
            {
                Key = "CMME-258959",
                Subject = "Event 19",
                StartDateTime = SmartDate.Parse("2/14/2012 12:00:00 AM"),
                EndDateTime = SmartDate.Parse("2/14/2012 12:00:00 AM"),
                AllDayEvent = true,
            });
        }

        private void FetchReminders(FetchRemindersContext context)
        {
            // there are no reminders to fetch
        }

        private void FetchRecurrences(FetchRecurrencesContext context)
        {
            // there are no recurring events to fetch
        }

        private void FetchVariances(FetchVariancesContext context)
        {
            // there are no recurring events with variance to fetch
        }

        #endregion

        #region IDataUpdate Members

        /// <summary>
        /// This method has no implementation.
        /// Interface IDataUpdate is only implemented because Infragistics cast the provider
        /// instead of checking wether the Interface is implemented. So an Exception would occour even if
        /// no Update happens.
        /// </summary>
        public void Update(DataContext context)
        {
        }

        #endregion

    }
}